@@ -6,7 +6,7 @@ use 5.006;
 use strict;
 use warnings;
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use File::Copy;
 use File::Path;
@@ -16,7 +16,7 @@ use LWP::Simple;
 use File::Basename;
 use File::Spec::Functions qw(rel2abs abs2rel);
 use Cwd;
-use File::Temp;
+use File::Temp qw(tempfile);
 
 our $DRY_RUN;
 our $CONFIRM;
@@ -82,6 +82,7 @@ hammer say
 sudo_me bin_find
 fs_read_open fs_write_open pipe_copy
 snip password_read nice_time
+def_or blurt_atomic
 );
 
 our %EXPORTABLE = map { $_ => 1 } @EXPORTABLE;
@@ -745,6 +746,8 @@ sub blurt {
 
     local($Log::Log4perl::caller_depth) += 1;
 
+    $append = 0 unless defined $append;
+
     _confirm(($append ? "Appending" : "Writing") . " " .
          length($data) . " bytes to $file") or return 1;
 
@@ -759,6 +762,36 @@ sub blurt {
 
 =pod
 
+=item C<blurt_atomic($data, $file)>
+
+Write the data in $data to a file $file, guaranteeing that the operation
+will either complete fully or not at all. This is accomplished by first
+writing to a temporary file which is then rename()ed to the target file.
+
+Unlike in C<blurt>, there is no C<$append> mode in C<blurt_atomic>.
+
+=cut
+
+###############################################
+sub blurt_atomic {
+###############################################
+    my($data, $file) = @_;
+
+    _confirm("Writing atomically " .
+         length($data) . " bytes to $file") or return 1;
+
+    my($fh, $tmpname) = tempfile(DIR => dirname($file));
+
+    blurt($data, $tmpname);
+
+    rename $tmpname, $file or
+        LOGDIE "Can't rename $tmpname to $file";
+
+    DEBUG "Wrote ", snip($data, $DATA_SNIPPED_LEN), " atomically to $file";
+}
+
+=pod
+
 =item C<($stdout, $stderr, $exit_code) = tap($cmd, @args)>
 
 Run a command $cmd in the shell, and pass it @args as args.
@@ -1366,10 +1399,10 @@ sub printable {
 
 =pod
 
-=item C<read_password($prompt)>
+=item C<password_read($prompt)>
 
 Reads in a password to be typed in by the user in noecho mode.
-A call to read_password("password: ") results in
+A call to password_read("password: ") results in
 
     password: ***** (stars aren't actually displayed)
 
@@ -1430,6 +1463,48 @@ sub nice_time {
      $hour, $min, $sec);
 }
 
+=item C<def_or($foo, $default)>
+
+Perl-5.9 added the //= construct, which helps assigning values to
+undefined variables. Instead of writing
+
+    if(!defined $foo) {
+        $foo = $default;
+    }
+
+you can just write
+
+    $foo //= $default;
+
+However, this is not available on older perl versions (although there's 
+source filter solutions). Often, people use
+
+    $foo ||= $default;
+
+instead which is wrong if $foo contains a value that evaluates as false.
+So Sysadm::Install, the everything-and-the-kitchen-sink under the CPAN
+modules, provides the function C<def_or()> which can be used like
+
+    def_or($foo, $default); 
+
+to accomplish the same as
+
+    $foo //= $default;
+
+How does it work, how does $foo get a different value, although it's 
+apparently passed in by value? Modifying $_[0] within the subroutine
+is an old Perl trick to do exactly that.
+
+=cut
+
+###########################################
+sub def_or($$) {
+###########################################
+    if(! defined $_[0]) {
+        $_[0] = $_[1];
+    }
+}
+
 =pod
 
 =back
